@@ -8,21 +8,20 @@ use IO::File;
 BEGIN {
     use Exporter ();
     use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-    $VERSION     = '1.0000';
+    $VERSION     = '1.0001';
     @ISA         = qw(Exporter);
     @EXPORT      = qw();
     @EXPORT_OK   = qw();
     %EXPORT_TAGS = ();
 }
 
-
 =head1 NAME
 
 Video::Dumper::QuickTime - Dump QuickTime movie file structure
 
 =head1 VERSION
 
-Version 1.0000
+Version 1.0001
 
 =head1 SYNOPSIS
 
@@ -43,6 +42,16 @@ The module is intended primarily as a diagnostic tool, although it would be
 possible to subclass Video::Dumper::QuickTime to extract various sections of a
 QuickTime file.
 
+=head1 Methods
+
+The methods fall into two groups - those required to use the method, and those
+useful for subclassing it.
+
+The general use methods are presented first, followed by the accessor and
+utility methods of more use in subclassing.
+
+=head2 General use methods
+
 =cut
 
 =head3 new
@@ -75,10 +84,10 @@ work to be done. A typical callback sub would look like:
 
 sub new {
     my $proto = shift;
-    my $class = ref($proto) || $proto;
+    my $class = ref ($proto) || $proto;
     my $self  = bless {}, $class;
 
-    $self = $self->_init(@_);
+    $self = $self->_init (@_);
 
     return $self;
 }
@@ -86,10 +95,10 @@ sub new {
 sub _init {
     my $self  = shift;
     my %param = @_;
-    $self->_init_attributes(@_);
+    $self->_init_attributes (@_);
     $self->{indentStr} ||= '.  ';
     $self->{indent}    ||= '';
-    $self->{result}    = '';
+    $self->{result}       = '';
     $self->{unknownAtoms} = {};
     return $self;
 }
@@ -99,7 +108,7 @@ sub _init_attributes {
     my %raw  = @_;
     my %param;
 
-    for ( keys %raw ) {
+    for (keys %raw) {
         /^-?(.+)/;
         $param{$1} = $raw{$_};
     }
@@ -111,7 +120,7 @@ sub _init_attributes {
     return if !defined $filename;
     $self->{filename} = $filename;
     $self->{filesize} = -s $filename;
-    $self->_openFile();
+    $self->_openFile ();
 }
 
 sub _openFile {
@@ -120,7 +129,7 @@ sub _openFile {
     $self->{nextUpdate} = $self->{filesize} / 100;
 
     my $fh = new IO::File;
-    $fh->open( $self->{filename} );
+    $fh->open ($self->{filename});
     $self->{handle} = $fh;
 }
 
@@ -129,60 +138,117 @@ sub _closeFile {
     my $fh   = new IO::File;
 
     return if !defined $self->{handle};
-    $self->{handle}->close();
+    $self->{handle}->close ();
 }
 
-sub read {
-    my $self = shift;
-    my ( $len, $offset ) = @_;
-    my $buf;
+=head3 Dump
 
-    seek $self->{handle}, $offset, 0 if defined $offset;
+Parse the movie file and return the result string.
 
-    my $n = read $self->{handle}, $buf, $len;
-    croak 'read failed'          unless defined $n;
-    die "end\n" if ! $n;
-    croak "short read ($len/$n)" unless $n == $len;
+=cut
 
-    if ( defined $self->{progress} ) {
-        $self->{parsedSize} += $n;
-
-        if ( $self->{nextUpdate} >= $self->{parsedSize} ) {
-            $self->{nextUpdate} += $self->{filesize} / 100;
-            $self->{progress}->( $self->{parsedSize}, $self->{filesize} );
-        }
-    }
-
-    return $buf;
-}
 
 sub Dump {    # Find top level atoms
     my $self = shift;
     my $pos  = 0;
 
     eval {
-        push @{ $self->{atomStack} }, ( [ 'global', {} ] );
-        $pos = $self->describeAtom($pos) while !eof( $self->{handle} );
+        push @{$self->{atomStack}}, (['global', {}]);
+        $pos = $self->describeAtom ($pos) while !eof ($self->{handle});
     };
 
-    $self->_closeFile();
+    $self->_closeFile ();
 
     die $@ if $@ and $@ ne "end\n";
     return $self->{result};
 }
 
+=head3 IndentStr
+
+Returns the string used for indenting in the result string.
+
+=cut
+
 sub IndentStr {
     my $self = shift;
 
     return $self->{indentStr};
 }
 
+=head3 Result
+
+C<Result> returns the result string generated by Dump. This can be usefull if
+you need to wrap the call the C<Dump> in an C<eval>, but still want any output
+that was generated in the case when an exception was thrown.
+
+=cut
+
 sub Result {
     my $self = shift;
 
     return $self->{result};
 }
 
+
+=head2 Subclassing utility methods
+
+The following methods are used internally to manipulate and decode the data in
+the movie file. The present documentation if rather scanty, but will be improved
+over time (sooner if you ask for it!).
+
+Generally the method name and parameter list are given. Parameters in C<[]> are
+optional. Parameters followed by C<...> may be repeated as required.
+
+=head3 read ($length[, $offset]);
+
+C<read> takes two parameters - a length (required) and a starting offset
+(optional).
+
+C<read> returns a string containing the number of bytes asked for starting from
+the current position or the given offset.
+
+C<read> will C<die "end\n";> if the end of the file is reached without reading
+any further bytes.
+
+C<read> will C<croak "short read ($len/$n)"> if fewer than the requested bytes
+are available.
+
+=cut
+
+sub read {
+    my $self = shift;
+    my ($len, $offset) = @_;
+    my $buf;
+
+    seek $self->{handle}, $offset, 0 if defined $offset;
+
+    my $n = read $self->{handle}, $buf, $len;
+    croak 'read failed' unless defined $n;
+    die "end\n" if !$n;
+    croak "short read ($len/$n)" unless $n == $len;
+
+    if (defined $self->{progress}) {
+        $self->{parsedSize} += $n;
+
+        if ($self->{nextUpdate} >= $self->{parsedSize}) {
+            $self->{nextUpdate} += $self->{filesize} / 100;
+            $self->{progress}->($self->{parsedSize}, $self->{filesize});
+        }
+    }
+
+    return $buf;
+}
+
+
+=head3 append ($str, ...)
+
+Append a list of strings to the result string.
+
+If the last character in the result string before the append was a new line
+character prepend the current indent string first.
+
+=cut
+
 sub append {
     my $self = shift;
     my $lastChar = substr $self->{result}, -1;
@@ -191,115 +257,200 @@ sub append {
     $self->{result} .= join '', @_;
 }
 
+
+=head3 findAtom ($attribute[, $regexp])
+
+Search down the atom stack for an atom with a matching attribute and return the
+atom if found,or undef if no matching atom is found.
+
+If the regular expression is provided the value of the attribute mustmatch
+against the regular expression. The regex should be generated using C<qr//>.
+
+See also L</setParentAttrib> and L</findAtomValue>
+
+=cut
+
 sub findAtom {
-    my ( $self, $attrib, $regexp ) = @_;
-    my $limit = @{ $self->{atomStack} };
+    my ($self, $attrib, $regexp) = @_;
+    my $limit = @{$self->{atomStack}};
     my $dataRef;
     my $index = -1;
 
-    while ( -$index < $limit ) {
-        $dataRef = \%{ $self->{atomStack}[ $index-- ][1] };
+    while (-$index < $limit) {
+        $dataRef = \%{$self->{atomStack}[$index--][1]};
         next if !exists $dataRef->{$attrib};
         last if !defined $regexp;
-        last if $dataRef->{$attrib} =~ /$regexp/;
+        last if $dataRef->{$attrib} =~ $regexp;
     }
 
     return $dataRef;
 }
 
+=head3 findAtomValue ($attribute[, $regexp])
+
+Search down the atom stack for an atom with a matching attribute and return the
+attribute value if found, or '' if no matching atom is found.
+
+If the regular expression is provided the value of the attribute mustmatch
+against the regular expression. The regex should be generated using C<qr//>.
+
+See also L</setParentAttrib> and L</findAtom>
+
+=cut
+
 sub findAtomValue {
-    my ( $self, $attrib, $regexp ) = @_;
-    my $dataRef = $self->findAtom( $attrib, $regexp );
+    my ($self, $attrib, $regexp) = @_;
+    my $dataRef = $self->findAtom ($attrib, $regexp);
 
     return $dataRef ? $dataRef->{$attrib} : '';
 }
 
+=head3 setParentAttrib ($attrib, $value)
+
+Set an attribute on the parent of the current atom.
+
+=cut
+
 sub setParentAttrib {
     my ($self, $attrib, $value) = @_;
     $self->{atomStack}[-2][1]{$attrib} = $value;
 }
 
+=head3 getParentAttribs
+
+Return a hash ref containing all the attribute => value pairs for the parent
+atom.
+
+=cut
+
 sub getParentAttribs {
     my ($self) = @_;
 
     return $self->{atomStack}[-2][1];
 }
 
+=head3 describeAtom ($pos)
+
+Add a descriptive header to the result string for the atom at the given
+position.
+
+If L</dump_xxxx> and L</name_xxxx> are available for the atom they are called to
+dump the atom's contents. If specific decoding is not available the atom is
+flagged as unknown and raw data for it is shown in the Dump result.
+
+=head3 dump_xxxx ($pos, $length)
+
+C<xxxx> is the four char code for an atom. C<name_xxxx> is called with the start
+and length of an atom of type C<xxxx> and is expected to decode the atom's
+contents.
+
+=head3 name_xxxx
+
+C<xxxx> is the four char code for an atom. C<name_xxxx> returns a string to be
+shown as the name for the atom C<xxxx>.
+
+=cut
+
 sub describeAtom {
     my $self = shift;
     my $pos  = shift;
-    my ( $len, $key ) = unpack( "Na4", $self->read( 8, $pos ) );
+    my ($len, $key) = unpack ("Na4", $self->read (8, $pos));
 
-    if ( !defined $len or $len == 0 ) {
-        $self->append("End entry\n");
+    if (!defined $len or $len == 0) {
+        $self->append ("End entry\n");
         return $pos + 4;
     }
 
-    $key = 'x' . unpack( 'H8', $key ) if $key =~ /[\x00-\x1f]/;
+    $key = 'x' . unpack ('H8', $key) if $key =~ /[\x00-\x1f]/;
     $key =~ tr/ /_/;
     $key =~ s/([^\w \d_])/sprintf "%02X", ord ($1)/ge;
 
-    if ( !length $key ) {
+    if (!length $key) {
         return $pos;
     }
 
     my $member = "dump_$key";
     my $name   = "name_$key";
 
-    $name = $self->can($name) ? $self->$name() . ' ' : '';
+    $name = $self->can ($name) ? $self->$name () . ' ' : '';
 
-    my $header = sprintf "'%s' %s@ %s (0x%08x) for %s (0x%08x):", $key,
-      $name, groupDigits($pos), $pos, groupDigits($len), $len;
+    my $header = sprintf "'%s' %s@ %s (0x%08x) for %s (0x%08x):", $key, $name,
+      groupDigits ($pos), $pos, groupDigits ($len), $len;
 
-    $self->append("$header\n");
+    $self->append ("$header\n");
     $self->{indent} .= $self->{indentStr};
-    if ( $self->can($member) ) {
-        push @{ $self->{atomStack} }, [ $key, {} ];
-        $self->$member( $pos, $len );
-        pop @{ $self->{atomStack} };
+    if ($self->can ($member)) {
+        push @{$self->{atomStack}}, [$key, {}];
+        $self->$member ($pos, $len);
+        pop @{$self->{atomStack}};
     }
     else {
-        $self->append( "   Unhandled: length = " . groupDigits($len) . "\n" );
-        $self->dumpBlock( $pos + 8, $len > 24 ? 16 : $len - 8 ) if $len > 8;
-        if ( !$self->{unknownAtoms}{$key}++ ) {
-            printf "Unknown atom '%s' %s (0x%08x) long at %s (0x%08x))\n",
-              $key, groupDigits($pos), $pos, groupDigits($len), $len;
+        $self->append ("   Unhandled: length = " . groupDigits ($len) . "\n");
+        $self->dumpBlock ($pos + 8, $len > 24 ? 16 : $len - 8) if $len > 8;
+        if (!$self->{unknownAtoms}{$key}++) {
+            printf "Unknown atom '%s' %s (0x%08x) long at %s (0x%08x))\n", $key,
+              groupDigits ($pos), $pos, groupDigits ($len), $len;
         }
     }
     $self->{indent} = substr $self->{indent}, length $self->{indentStr};
     return $pos + $len;
 }
 
+=head3 describeAtoms ($pos, $count)
+
+Calls L</describeAtom> for each of $count atoms starting at $pos.
+
+=cut
+
 sub describeAtoms {
     my $self = shift;
-    my ( $pos, $count ) = @_;
+    my ($pos, $count) = @_;
 
-    $pos = $self->describeAtom($pos) while $count--;
+    $pos = $self->describeAtom ($pos) while $count--;
     return $pos;
 }
 
+=head3 describeAtomsIn ($pos, $end)
+
+Calls L</describeAtom> for each atom starting at $pos and before $end.
+
+=cut
+
 sub describeAtomsIn {
     my $self = shift;
-    my ( $pos, $end ) = @_;
+    my ($pos, $end) = @_;
 
-    $pos = $self->describeAtom($pos) while $pos < $end;
+    $pos = $self->describeAtom ($pos) while $pos < $end;
 }
 
+=head3 unwrapAtoms ($pos, $len)
+
+Calls L</describeAtomsIn> for each atom in the given range. Used to decode an
+atom that is purely a container for other atoms.
+
+=cut
+
 sub unwrapAtoms {
     my $self = shift;
-    my ( $pos, $len ) = @_;
+    my ($pos, $len) = @_;
 
-    $self->describeAtomsIn( $pos + 8, $pos + $len );
+    $self->describeAtomsIn ($pos + 8, $pos + $len);
 }
 
+=head3 atomList ($pos, $len)
+
+Dump a version and flags header followed by a list of atoms.
+
+=cut
+
 sub atomList {
     my $self = shift;
-    my ( $pos, $len ) = @_;
+    my ($pos, $len) = @_;
 
-    $self->append( 'Version:  ', unpack( 'C',   $self->read(1) ), "\n" );
-    $self->append( 'Flags:    ', unpack( 'B24', $self->read(3) ), "\n" );
-    NToSigned( $self->read(4) );
-    $self->describeAtomsIn( $pos + 16, $pos + $len );
+    $self->append ('Version:  ', unpack ('C',   $self->read (1)), "\n");
+    $self->append ('Flags:    ', unpack ('B24', $self->read (3)), "\n");
+    NToSigned ($self->read (4));
+    $self->describeAtomsIn ($pos + 16, $pos + $len);
 }
 
 #sub construct_hash {
@@ -324,32 +475,32 @@ sub atomList {
 
 sub dump_A9cmt {
     my $self = shift;
-    $self->showStr(@_);
+    $self->showStr (@_);
 }
 
 sub dump_A9cpy {
     my $self = shift;
-    $self->showStr(@_);
+    $self->showStr (@_);
 }
 
 sub dump_A9des {
     my $self = shift;
-    $self->showStr(@_);
+    $self->showStr (@_);
 }
 
 sub dump_A9inf {
     my $self = shift;
-    $self->showStr(@_);
+    $self->showStr (@_);
 }
 
 sub dump_A9nam {
     my $self = shift;
-    $self->showStr(@_);
+    $self->showStr (@_);
 }
 
 sub dump_actn {
     my $self = shift;
-    my ( $pos, $len ) = @_;
+    my ($pos, $len) = @_;
     my %actionTypes = (
         1  => 'mcActionIdle',
         2  => 'mcActionDraw',
@@ -422,10 +573,10 @@ sub dump_actn {
         81 => 'mcActionLinkToURLExtended',
     );
 
-    my $type = $actionTypes{ NToSigned( $self->read(4) ) } || 'unknown';
-    $self->append("Action type: $type\n");
-    $self->append("Reserved\n");
-    $self->unwrapAtoms( $pos + 12, $len - 12 );
+    my $type = $actionTypes{NToSigned ($self->read (4))} || 'unknown';
+    $self->append      ("Action type: $type\n");
+    $self->append      ("Reserved\n");
+    $self->unwrapAtoms ($pos + 12, $len - 12);
 }
 
 sub name_actn {
@@ -435,9 +586,9 @@ sub name_actn {
 
 sub dump_alis {
     my $self = shift;
-    my ( $pos, $len ) = @_;
+    my ($pos, $len) = @_;
 
-    $self->append( 'File #', groupDigits( NToSigned( $self->read(4) ) ), "\n" );
+    $self->append ('File #', groupDigits (NToSigned ($self->read (4))), "\n");
 }
 
 sub name_alis {
@@ -830,12 +981,12 @@ sub name_minf {
 
 sub dump_mmdr {
     my $self = shift;
-    my ( $pos, $len ) = @_;
+    my ($pos, $len) = @_;
 
-    $self->showBogus();
-    $self->append( 'Unknown:  ', $self->get4Char(), "\n" );
-    $self->append( 'Unknown:  ', NToSigned( $self->read(4) ), "\n" );
-    $self->unwrapAtoms( $pos + 21, $len - 21 );
+    $self->showBogus ();
+    $self->append    ('Unknown:  ', $self->get4Char (), "\n");
+    $self->append    ('Unknown:  ', NToSigned ($self->read (4)), "\n");
+    $self->unwrapAtoms ($pos + 21, $len - 21);
 }
 
 sub name_mmdr {
@@ -1165,27 +1316,27 @@ sub name_stbl {
 
 sub dump_stco {
     my $self = shift;
-    my ( $pos, $len ) = @_;
-    my $dataRef = $self->findAtom( 'HdlrSubCmpt', '^(?!alis)' );
+    my ($pos, $len) = @_;
+    my $dataRef = $self->findAtom ('HdlrSubCmpt', qr'^(?!alis)');
 
-    $self->append( 'Version:  ', unpack( 'C',   $self->read(1) ), "\n" );
-    $self->append( 'Flags:    ', unpack( 'B24', $self->read(3) ), "\n" );
+    $self->append ('Version:  ', unpack ('C',   $self->read (1)), "\n");
+    $self->append ('Flags:    ', unpack ('B24', $self->read (3)), "\n");
 
-    my $entries = NToSigned( $self->read(4) );
+    my $entries = NToSigned ($self->read (4));
     my $digits  = length $entries;
-    my $type    = ( defined $dataRef && $dataRef->{'HdlrSubCmpt'} ) || '';
+    my $type    = (defined $dataRef && $dataRef->{'HdlrSubCmpt'}) || '';
     $pos += 16;
 
-    for ( 1 .. $entries ) {
-        my $off = NToSigned( $self->read( 4, $pos ) );
+    for (1 .. $entries) {
+        my $off = NToSigned ($self->read (4, $pos));
         $pos += 4;
-        $self->append( sprintf( "  %*d ", $digits, $_ ) );
-        $self->append( "$type @ ", sprintf "%d (0x%04x)\n", $off, $off );
-        if ( $type =~ /sprt|moov/ ) {
-            $self->describeAtom( $off + 12 );
+        $self->append (sprintf ("  %*d ", $digits, $_));
+        $self->append ("$type @ ", sprintf "%d (0x%04x)\n", $off, $off);
+        if ($type =~ /sprt|moov/) {
+            $self->describeAtom ($off + 12);
         }
-        elsif ( $type eq 'vide' ) {
-            $self->append("    Not expanded\n");
+        elsif ($type eq 'vide') {
+            $self->append ("    Not expanded\n");
         }
         else {
             print "stco doesn't handle $type chunks\n";
@@ -1550,10 +1701,10 @@ sub name_wide {
 
 sub dump_WLOC {
     my $self = shift;
-    my ( $pos, $len ) = @_;
+    my ($pos, $len) = @_;
 
     $len = 2 * $len - 16;
-    $self->append( unpack( "H$len\n", $self->read($len) ), "\n" );
+    $self->append (unpack ("H$len\n", $self->read ($len)), "\n");
 }
 
 sub name_WLOC {
@@ -1565,16 +1716,16 @@ sub dump_x00000001 {
     my $self       = shift;
     my $parentType = $self->{atomStack}[-2][0];
 
-    if ( $parentType eq 'oprn' ) {
-        my ( $pos, $len ) = @_;
+    if ($parentType eq 'oprn') {
+        my ($pos, $len) = @_;
 
-        $self->showUnknown();
-        $self->unwrapAtoms( $pos + 12, $len - 12 );
+        $self->showUnknown ();
+        $self->unwrapAtoms ($pos + 12, $len - 12);
     }
     else {
 
-        $self->showBogus();
-        $self->append( 'Matrix structure:  ', $self->showMatrix(), "\n" );
+        $self->showBogus ();
+        $self->append ('Matrix structure:  ', $self->showMatrix (), "\n");
     }
 }
 
@@ -1582,7 +1733,7 @@ sub name_x00000001 {
     my $self       = shift;
     my $parentType = $self->{atomStack}[-2][0];
 
-    if ( $parentType eq 'oprn' ) {
+    if ($parentType eq 'oprn') {
         return '';
     }
     else {
@@ -1593,9 +1744,9 @@ sub name_x00000001 {
 sub dump_x00000002 {
     my $self = shift;
 
-    $self->showUnknown();
-    $self->append( 'Value:     ', groupDigits( nToSigned( $self->read(2) ) ),
-        "\n" );
+    $self->showUnknown ();
+    $self->append ('Value:     ', groupDigits (nToSigned ($self->read (2))),
+        "\n");
 }
 
 sub name_x00000002 {
@@ -1606,8 +1757,8 @@ sub name_x00000002 {
 sub dump_x00000004 {
     my $self = shift;
 
-    $self->showBogus();
-    $self->append( 'Visible:  ', nToSigned( $self->read(2) ), "\n" );
+    $self->showBogus ();
+    $self->append ('Visible:  ', nToSigned ($self->read (2)), "\n");
 }
 
 sub name_x00000004 {
@@ -1618,8 +1769,8 @@ sub name_x00000004 {
 sub dump_x00000005 {
     my $self = shift;
 
-    $self->showBogus();
-    $self->append( 'Layer:  ', nToSigned( $self->read(2) ), "\n" );
+    $self->showBogus ();
+    $self->append ('Layer:  ', nToSigned ($self->read (2)), "\n");
 }
 
 sub name_x00000005 {
@@ -1630,9 +1781,9 @@ sub name_x00000005 {
 sub dump_x00000006 {
     my $self = shift;
 
-    $self->showPlayMode();
-    $self->showBogus();
-    $self->showRGB();
+    $self->showPlayMode ();
+    $self->showBogus    ();
+    $self->showRGB      ();
 }
 
 sub name_x00000006 {
@@ -1650,8 +1801,8 @@ sub name_x00000015 {
 
 sub dump_x00000064 {
     my $self = shift;
-    $self->showBogus();
-    $self->append( 'Image index: ', nToSigned( $self->read(2) ), "\n" );
+    $self->showBogus ();
+    $self->append ('Image index: ', nToSigned ($self->read (2)), "\n");
 }
 
 sub name_x00000064 {
@@ -1662,9 +1813,9 @@ sub name_x00000064 {
 sub dump_x00000065 {
     my $self = shift;
 
-    $self->append("Background colour:\n");
-    $self->showBogus();
-    $self->showRGB();
+    $self->append    ("Background colour:\n");
+    $self->showBogus ();
+    $self->showRGB   ();
 }
 
 sub name_x00000065 {
@@ -1674,8 +1825,8 @@ sub name_x00000065 {
 
 sub dump_x00000066 {
     my $self = shift;
-    $self->showBogus();
-    $self->append( 'Offscreen bit depth: ', nToSigned( $self->read(2) ), "\n" );
+    $self->showBogus ();
+    $self->append ('Offscreen bit depth: ', nToSigned ($self->read (2)), "\n");
 }
 
 sub name_x00000066 {
@@ -1685,8 +1836,8 @@ sub name_x00000066 {
 
 sub dump_x00000067 {
     my $self = shift;
-    $self->showBogus();
-    $self->append( 'Sample format: ', nToSigned( $self->read(2) ), "\n" );
+    $self->showBogus ();
+    $self->append ('Sample format: ', nToSigned ($self->read (2)), "\n");
 }
 
 sub name_x00000067 {
@@ -1696,8 +1847,8 @@ sub name_x00000067 {
 
 sub dump_x00000069 {
     my $self = shift;
-    $self->showBogus();
-    $self->append( 'Has Actions: ', cToBool( $self->read(1) ), "\n" );
+    $self->showBogus ();
+    $self->append ('Has Actions: ', cToBool ($self->read (1)), "\n");
 }
 
 sub name_x00000069 {
@@ -1707,8 +1858,8 @@ sub name_x00000069 {
 
 sub dump_x0000006a {
     my $self = shift;
-    $self->showBogus();
-    $self->append( 'Visible: ', cToBool( $self->read(1) ), "\n" );
+    $self->showBogus ();
+    $self->append ('Visible: ', cToBool ($self->read (1)), "\n");
 }
 
 sub name_x0000006a {
@@ -1718,13 +1869,13 @@ sub name_x0000006a {
 
 sub dump_x0000006b {
     my $self = shift;
-    $self->showBogus();
+    $self->showBogus ();
 
-    my $interval = NToUnsigned( $self->read(4) );
-    my $freq = $interval ? ( 60.0 / $interval ) . ' Hz' : 'fastest';
+    my $interval = NToUnsigned ($self->read (4));
+    my $freq = $interval ? (60.0 / $interval) . ' Hz' : 'fastest';
 
     $freq = 'off' if $interval == 0xffffffff;
-    $self->append("Idle Events: $freq\n");
+    $self->append ("Idle Events: $freq\n");
 }
 
 sub name_x0000006b {
@@ -1790,11 +1941,11 @@ sub name_x00000c06 {
 
 sub dump_x00000c07 {
     my $self = shift;
-    my ( $pos, $len ) = @_;
+    my ($pos, $len) = @_;
 
     $self->setParentAttribs (ActionType => 'kOperandSpriteTrackVariable');
-    $self->showUnknown();
-    $self->unwrapAtoms( $pos + 12, $len - 12 );
+    $self->showUnknown ();
+    $self->unwrapAtoms ($pos + 12, $len - 12);
 }
 
 sub name_x00000c07 {
@@ -1826,88 +1977,105 @@ sub name_x00001402 {
     return 'kOperandKeyIsDown';
 }
 
+=head3 dumpBlock
+
+    $self->dumpBlock ($pos + 8, $len - 8);
+
+Dump a raw block of data. Generally used where the block can not be further
+decoded.
+
+=cut
+
 sub dumpBlock {
     my $self = shift;
-    my ( $pos, $len ) = @_;
+    my ($pos, $len) = @_;
 
     while ($len) {
         my $chunk = $len > 16 ? 16 : $len;
-        my $str = $self->read($chunk);
+        my $str = $self->read ($chunk);
 
         $str =~ s/([\x00-\x1f\x80-\xff])/sprintf "\\x%02x", ord ($1)/ge;
-        $self->append("$str\n");
+        $self->append ("$str\n");
         $len -= $chunk;
     }
 }
 
+=head3 dumpText ($pos, $len)
+
+Append an ASCII string starting at $pos for $len characters to the Dump result.
+
+=cut
+
 sub dumpText {
     my $self = shift;
-    my ( $pos, $len ) = @_;
+    my ($pos, $len) = @_;
 
-    $self->append( unpack( "a$len", $self->read($len) ), "\n" );
+    $self->append (unpack ("a$len", $self->read ($len, $pos)), "\n");
 }
 
+=head3 dumpUnicodeText
+
+Append a utf16 string starting at $pos for $len bytes to the Dump result.
+
+=cut
+
 sub dumpUnicodeText {
     my $self = shift;
-    my ( $pos, $len ) = @_;
+    my ($pos, $len) = @_;
 
-    my $rawStr = "\xff\xfe" . unpack( "a$len", $self->read($len) );
-    my $str = decode( "utf16", $rawStr );
-    $self->append( $str, "\n" );
+    my $rawStr = "\xff\xfe" . unpack ("a$len", $self->read ($len, $pos));
+    my $str = decode ("utf16", $rawStr);
+    $self->append ($str, "\n");
 }
 
-sub groupDigits {
-    my $num = reverse shift;
+=head3 showBogus
 
-    $num =~ s/(\d{3}(?=\d))/$1,/g;
-    return scalar reverse $num;
-}
+L</appends> the next four bytes as a packed version and flags field then skips eight
+bytes.
 
-sub show {
-    local $_;
-    my $thing = shift;
-    if ( $thing =~ /^([^\x00]*)\x00\Z/ ) {
-        return $1;
-    }
-    elsif ( $thing =~ /[\x00-\x1f]/ ) {
-        my $sum = 0;
-        my @chars = split '', $thing;
-        $sum = $sum * 256 + ord($_) for @chars;
-        return sprintf "0x%0x", $sum;
-    }
-
-    return $thing;
-}
+=cut
 
 sub showBogus {
     my $self = shift;
 
-    $self->append( 'Version:  ', unpack( 'C',   $self->read(1) ), "\n" );
-    $self->append( 'Flags:    ', unpack( 'B24', $self->read(3) ), "\n" );
-    $self->append("Reserved\n");
-    $self->read(8);
+    $self->append ('Version:  ', unpack ('C',   $self->read (1)), "\n");
+    $self->append ('Flags:    ', unpack ('B24', $self->read (3)), "\n");
+    $self->append ("Reserved\n");
+    $self->read   (8);
 }
 
+=head3 showPlayMode
+
+L</appends> a play mode string decoded from the next four byte flags field.
+
+=cut
+
 sub showPlayMode {
     my $self     = shift;
     my $flagBits = shift;
     my $flags    = '';
 
-    $flagBits = $self->read(4) if !defined $flagBits;
-    $flagBits = NToSigned($flagBits);
+    $flagBits = $self->read (4) if !defined $flagBits;
+    $flagBits = NToSigned ($flagBits);
 
     $flags .= 'fullScreenHideCursor '        if $flags & 1;
     $flags .= 'fullScreenAllowEvents '       if $flags & 2;
     $flags .= 'fullScreenDontChangeMenuBar ' if $flags & 4;
     $flags .= 'fullScreenPreflightSize '     if $flags & 8;
-    $self->append("Play mode flags: $flags\n");
+    $self->append ("Play mode flags: $flags\n");
 }
 
+=head3 showGMode
+
+L</appends> a graphics mode line decoded from the next two byte field.
+
+=cut
+
 sub showGMode {
     my $self  = shift;
     my $gMode = shift;
-    $gMode = $self->read(2) if !defined $gMode;
-    $gMode = NToSigned($gMode);
+    $gMode = $self->read (2) if !defined $gMode;
+    $gMode = NToSigned ($gMode);
 
     my %modes = (
         0x0000 => 'Copy',
@@ -1921,31 +2089,43 @@ sub showGMode {
         0x0103 => 'Composition (dither copy)',
     );
 
-    $self->append("Graphics mode: $modes{$gMode}\n");
+    $self->append ("Graphics mode: $modes{$gMode}\n");
 }
 
+=head3 showRGB
+
+L</appends> three RGB color lines decoded from the next six bytes.
+
+=cut
+
 sub showRGB {
     my $self = shift;
-    my ( $red, $green, $blue ) = @_;
+    my ($red, $green, $blue) = @_;
 
-    $red   = $self->read(2) if !defined $red;
-    $green = $self->read(2) if !defined $green;
-    $blue  = $self->read(2) if !defined $blue;
-    $red   = nToUnsigned($red);
-    $green = nToUnsigned($green);
-    $blue  = nToUnsigned($blue);
+    $red   = $self->read (2) if !defined $red;
+    $green = $self->read (2) if !defined $green;
+    $blue  = $self->read (2) if !defined $blue;
+    $red   = nToUnsigned ($red);
+    $green = nToUnsigned ($green);
+    $blue  = nToUnsigned ($blue);
 
-    $self->append("Red:   $red\n");
-    $self->append("Green: $green\n");
-    $self->append("Blue:  $blue\n");
+    $self->append ("Red:   $red\n");
+    $self->append ("Green: $green\n");
+    $self->append ("Blue:  $blue\n");
 }
 
+=head3 showGraphicsXferMode
+
+L</appends> a graphics transfer mode string decoded fromthe next two byte field.
+
+=cut
+
 sub showGraphicsXferMode {
     my $self  = shift;
     my $gMode = shift;
 
-    $gMode = $self->read(2) if !defined $gMode;
-    $gMode = nToSigned($gMode);
+    $gMode = $self->read (2) if !defined $gMode;
+    $gMode = nToSigned ($gMode);
 
     my %modes = (
         0  => 'srcCopy',
@@ -1979,128 +2159,244 @@ sub showGraphicsXferMode {
         36 => 'transparent',
     );
 
-    if ( exists $modes{$gMode} ) {
-        $self->append( 'Mode:  ', $modes{$gMode}, "\n" );
+    if (exists $modes{$gMode}) {
+        $self->append ('Mode:  ', $modes{$gMode}, "\n");
     }
     else {
-        $self->append( 'Mode:  unknown - ', $gMode, "\n" );
+        $self->append ('Mode:  unknown - ', $gMode, "\n");
     }
 }
 
+=head3 showDate
+
+L</appends> a date string decoded from the next four bytes.
+
+=cut
+
 sub showDate {
     my $self  = shift;
     my $stamp = shift;
 
-    $stamp = $self->read(4) if !defined $stamp;
-    $stamp = NToUnsigned($stamp);
+    $stamp = $self->read (4) if !defined $stamp;
+    $stamp = NToUnsigned ($stamp);
 
     # seconds difference between Mac epoch and Unix/Windows.
     my $mod =
-        ( $^O =~ /MSWin32/ )
-      ? ( 2063824538 - 12530100 + 31536000 )
-      : ( 2063824538 - 12530100 );
-    my $date =
-      ( $^O =~ /Mac/ ) ? localtime($stamp) : localtime( $stamp - $mod );
+        ($^O =~ /MSWin32/)
+      ? (2063824538 - 12530100 + 31536000)
+      : (2063824538 - 12530100);
+    my $date = ($^O =~ /Mac/) ? localtime ($stamp) : localtime ($stamp - $mod);
     return $date;
 }
 
+=head3 showMatrix ([$matrix])
+
+Returns a matrix string formedby decoding the 36 byte contents of $matrix or the
+next 36 bytes (if $matrix is not provided).
+
+=cut
+
 sub showMatrix {
     my $self   = shift;
     my $matrix = shift;
 
-    $matrix = $self->read(36) if !defined $matrix;
+    $matrix = $self->read (36) if !defined $matrix;
 
     my $str = '';
-    for ( 1 .. 3 ) {
+    for (1 .. 3) {
         my $sub = substr $matrix, 0, 12, '';
-        $str .= NToFixed( substr $sub, 0, 4, '' ) . ' ';
-        $str .= NToFixed( substr $sub, 0, 4, '' ) . ' ';
-        $str .= NToFrac( substr $sub, 0, 4, '' ) . ' ';
+        $str .= NToFixed (substr $sub, 0, 4, '') . ' ';
+        $str .= NToFixed (substr $sub, 0, 4, '') . ' ';
+        $str .= NToFrac (substr $sub, 0, 4, '') . ' ';
         $str .= ' / ' if $_ != 3;
     }
 
     return $str;
 }
 
+=head3 showStr ($pos)
+
+L</appends> the length prefixed string starting at $pos.
+
+=cut
+
 sub showStr {
     my $self = shift;
     my $pos  = shift;
-    my ( $len, $key ) = unpack( "Na4", $self->read( 8, $pos ) );
+    my ($len, $key) = unpack ("Na4", $self->read (8, $pos));
 
     $len -= 12;
-    $self->append( unpack( "a$len", $self->read( $len, $pos + 12 ) ), "\n" );
+    $self->append (unpack ("a$len", $self->read ($len, $pos + 12)), "\n");
 }
 
+=head3 showUnknown
+
+L</append> out the next 12 bytes as three unknown signed numbers.
+
+=cut
+
 sub showUnknown {
     my $self = shift;
 
-    $self->append( 'Unknown 1: ', groupDigits( NToSigned( $self->read(4) ) ),
-        "\n" );
-    $self->append( 'Unknown 2: ', groupDigits( NToSigned( $self->read(4) ) ),
-        "\n" );
-    $self->append( 'Unknown 3: ', groupDigits( NToSigned( $self->read(4) ) ),
-        "\n" );
+    $self->append ('Unknown 1: ', groupDigits (NToSigned ($self->read (4))),
+        "\n");
+    $self->append ('Unknown 2: ', groupDigits (NToSigned ($self->read (4))),
+        "\n");
+    $self->append ('Unknown 3: ', groupDigits (NToSigned ($self->read (4))),
+        "\n");
 }
 
+=head3 get4Char
+
+Return the next four bytes as a four char code.
+
+=cut
+
 sub get4Char {
     my $self = shift;
-    return unpack( "a4", $self->read(4) );
+    return unpack ("a4", $self->read (4));
 }
 
+=head2 Helper functions
+
+The following functions are not object members and should be called as:
+
+    my $result = Video::Dumper::QuickTime::functionName (...);
+
+=head3 groupDigits ($number)
+
+Inserts commas into a number to group the digits into groups of 3.
+
+=cut
+
+sub groupDigits {
+    my $num = reverse shift;
+
+    $num =~ s/(\d{3}(?=\d))/$1,/g;
+    return scalar reverse $num;
+}
+
+=head3 show ($string)
+
+Attempt to make sense of the series of bytes in $string. Maybe useful for
+attempting to make sense of unknown atom data.
+
+=cut
+
+sub show {
+    local $_;
+    my $thing = shift;
+    if ($thing =~ /^([^\x00]*)\x00\Z/) {
+        return $1;
+    }
+    elsif ($thing =~ /[\x00-\x1f]/) {
+        my $sum = 0;
+        my @chars = split '', $thing;
+        $sum = $sum * 256 + ord ($_) for @chars;
+        return sprintf "0x%0x", $sum;
+    }
+
+    return $thing;
+}
+
+=head2 Conversion helper functions
+
+The following non-member function unpack strings of bytes into another
+representation.
+
+=head3 NToFixed ($str)
+
+=cut
+
 sub NToFixed {
     my $str = shift;
-    return unpack( 'l', pack( 'l', unpack( "N", $str ) ) ) / 0x10000;
+    return unpack ('l', pack ('l', unpack ("N", $str))) / 0x10000;
 }
 
+=head3 fToFloat ($str)
+
+=cut
+
 sub fToFloat {
     my $str = shift;
-    return unpack( 'l', pack( 'l', unpack( "f", $str ) ) );
+    return unpack ('l', pack ('l', unpack ("f", $str)));
 }
 
+=head3 NToFrac
+
+=cut
+
 sub NToFrac {
     my $str = shift;
-    my $fract = unpack( 'l', pack( 'l', unpack( "N", $str ) ) );
+    my $fract = unpack ('l', pack ('l', unpack ("N", $str)));
     return $fract / 0x40000000;
 }
 
+=head3 NToSigned
+
+=cut
+
 sub NToSigned {
     my $str = shift;
-    return unpack( 'l', pack( 'l', unpack( "N", $str ) ) );
+    return unpack ('l', pack ('l', unpack ("N", $str)));
 }
 
+=head3 NToUnsigned
+
+=cut
+
 sub NToUnsigned {
     my $str = shift;
-    return unpack( 'L', pack( 'L', unpack( "N", $str ) ) );
+    return unpack ('L', pack ('L', unpack ("N", $str)));
 }
 
+=head3 NToHex
+
+=cut
+
 sub NToHex {
     my $str = shift;
-    return '0x' . unpack( 'H8', pack( 'L', unpack( "N", $str ) ) );
+    return '0x' . unpack ('H8', pack ('L', unpack ("N", $str)));
 }
 
+=head3 NToBin
+
+=cut
+
 sub NToBin {
     my $str = shift;
-    return unpack( 'B32', pack( 'L', unpack( "N", $str ) ) );
+    return unpack ('B32', pack ('L', unpack ("N", $str)));
 }
 
+=head3 nToSigned
+
+=cut
+
 sub nToSigned {
     my $str = shift;
-    return unpack( 's', pack( 's', unpack( "n", $str ) ) );
+    return unpack ('s', pack ('s', unpack ("n", $str)));
 }
 
+=head3 nToUnsigned
+
+=cut
+
 sub nToUnsigned {
     my $str = shift;
-    return unpack( 'S', pack( 'S', unpack( "n", $str ) ) );
+    return unpack ('S', pack ('S', unpack ("n", $str)));
 }
 
+=head3 cToBool
+
+=cut
+
 sub cToBool {
     my $str = shift;
-    return ord($str);
+    return ord ($str);
 }
 
 1;
 
-
 =head2 Subclassing QuickTime
 
 Because there are a huge number of atom types used by QuickTime (many of them
@@ -2203,7 +2499,5 @@ it and/or modify it under the same terms as Perl itself.
 The full text of the license can be found in the
 LICENSE file included with this module.
 
-=head1 SEE ALSO
-
 =cut
 
